@@ -1,17 +1,17 @@
 familyStructure <-
-function (i, cumind=cumind, m.carrier=1, interaction=TRUE, depend=1, parms=c(0.016, 3), base.dist="Weibull", frailty.dist="gamma",
-            vbeta=c(-1.13, 2.35, 0.5), dominant.m=TRUE, dominant.s= TRUE, 
-            variation="secondgene", allelefreq= c(0.02, 0.2), mrate=0, 
-            probandage=c(45,1.5), agemin=20, agemax=100)
+function (i, cumind = cumind, m.carrier = 1, variation = "none", interaction = FALSE, 
+          add.x = FALSE, x.dist = NULL, x.parms = NULL, depend = NULL, 
+          base.dist = "Weibull", frailty.dist = NULL, base.parms = c(0.016, 3), 
+          vbeta = c(1, 1), allelefreq = 0.02, dominant.m = TRUE, dominant.s = TRUE, 
+          mrate = 0, probandage = c(45, 2), agemin = 20, agemax = 100)
 {
-    
-tmpdata<-numeric()
-indID<-c(cumind+1,cumind+2)
-motherID<-c(0,0) 
-fatherID<-c(0,0) 
-gender<-c(1,0) ## 0--Female, 1--Male
-proband<-c(0,0) ## 0--Non-proband,  1-- proband
-generation<-c(1,1) ## generation number, 0 in second generation means married from outside
+tmpdata <- numeric()
+indID <- c(cumind+1,cumind+2)
+motherID <- c(0,0) 
+fatherID <- c(0,0) 
+gender <- c(1,0) ## 0--Female, 1--Male
+proband <- c(0,0) ## 0--Non-proband,  1-- proband
+generation <- c(1,1) ## generation number, 0 in second generation means married from outside
 relation <- c(4,4)  #1=proband, 2=sib, 3=child, 4=parent, 5=sibchild, 6=hasband, 7=sibspouse  
 # SecNum <- 2, we can fix the number of sibs in second generation (eg., 2 sibs)
 
@@ -76,28 +76,36 @@ if (SecNum > 0) { ## at least one sample in second generation
     } #Close for  for (j in 1:SecNum)
       
   nIndi <- length(indID)     
-  famID<-rep(i, nIndi)    
-  ageonset<-rep(0, nIndi)      ## age at onset
-  censorage<-rep(0, nIndi)     ## current age
-  status<-rep(0, nIndi)        ## disease staus
+  famID <- rep(i, nIndi)    
+  ageonset <- rep(0, nIndi)      ## age at onset
+  censorage <- rep(0, nIndi)     ## current age
+  status <- rep(0, nIndi)        ## disease staus
   affected <- rep(0, nIndi)	
   disgene.m <- rep(0, nIndi)	
   disgene.s <- rep(0, nIndi)	
   ParentsG.m <- rep(0, nIndi)  ## parents genotype; it can be 1 to 9; 0 if founders
   pos <- c(1:nIndi) 
   
-  
   #------------------------------------------------------------------------------
   # Familial correlation will be generated by gamma frailty, log-normal frailty, or secondgene
       
-  ## Log-normal frailty (logX~Normal with mean=0, variance=depend)
+  ## Log-normal frailty (logX~Normal with mean=0, variance=1/depend)
   if (is.null(frailty.dist)) alpha=0
   else if (frailty.dist=="lognormal") alpha <- rnorm(1, mean=0, sd=1/sqrt(depend))
-  ## Gamma Frailty (with mean 1, variance=depend)
+  ## Gamma Frailty (with mean 1, variance=1/depend)
   else if (frailty.dist=="gamma") alpha <- log(rgamma(1, shape=depend, scale=1/depend))
   else stop("unrecognized frailty distribution")
   
-
+  #------------------------------------------------------------------------------
+  # variation is kinship
+  ## library(kinship2)
+  if (variation == 'kinship'){
+    sex <- ifelse(gender == 1, 'male', 'female')
+    mped <- pedigree(indID, fatherID, motherID, sex = sex, famid = famID)
+    kmat <- as.matrix(kinship(mped))
+    alpha <- mvrnorm(1, mu = rep(0,nrow(kmat)), Sigma = 2*kmat*depend)
+  }
+  
   #------------------------------------------------------------------------------
   ###  Generating the current age
   # First generation with default mean 65 and sd=2.5; Second gen with default mean 45 and sd=2.5; third gene has mean age difference of 20 with their parents and sd=1
@@ -125,6 +133,15 @@ if (SecNum > 0) { ## at least one sample in second generation
       }#Close for for(k in 1:length(sonpos))
     }#Close for for (j in 1:length(genepos))
       
+  
+  #------------------------------------------------------------------------------
+  # generate additional covariate
+  if(add.x){
+    if(x.dist =="normal") newx <- rnorm(nIndi, mean=x.parms[1], sd=x.parms[2])
+    else if(x.dist =="binomial") newx <- rbinom(nIndi, size = x.parms[1], prob = x.parms[2])
+  }
+  
+  
   #------------------------------------------------------------------------------
             
   if(length(allelefreq)==1) allelefreq <- c(allelefreq,0) 
@@ -139,7 +156,21 @@ if (SecNum > 0) { ## at least one sample in second generation
   # Generate proband's genotype given its age at onset and gender
   prob.age <- censorage[proband==1] # proband's current age
   prob.sex <- gender[proband==1]
-  pGene <- fgene(base.dist, frailty.dist, depend=depend, affage=prob.age-agemin, affsex=prob.sex, interaction=interaction, variation=variation, parms=parms, vbeta=vbeta, alpha=alpha, pg=0, m.carrier=m.carrier, dominant.m=dominant.m, aq = allelefreq)
+  if(add.x) prob.x <- newx[proband==1]
+  
+  if(variation == "kinship"){
+    prob.alpha <- alpha[proband == 1]
+  } else prob.alpha = alpha
+  
+  if(add.x) pGene <- fgeneZX(base.dist, frailty.dist, depend=depend, affage=prob.age-agemin, 
+                           affsex=prob.sex, affx = prob.x, interaction=interaction, variation=variation, 
+                           base.parms=base.parms, vbeta=vbeta, alpha=prob.alpha, pg=c(0,0), m.carrier=m.carrier, 
+                           dominant.m=dominant.m, aq = allelefreq)
+  else   pGene <- fgeneZ(base.dist, frailty.dist, depend=depend, affage=prob.age-agemin, 
+                            affsex=prob.sex, interaction=interaction, variation=variation, 
+                            base.parms=base.parms, vbeta=vbeta, alpha=prob.alpha, pg=c(0,0), m.carrier=m.carrier, 
+                            dominant.m=dominant.m, aq = allelefreq)
+
   #------------------------------------------------------------------------------ 
      
   if(variation=="secondgene") ngene <- c(1,2)
@@ -209,17 +240,16 @@ if (SecNum > 0) { ## at least one sample in second generation
       }
   else secondgene <- rep(0, nIndi)
       
+  
+  
   #------------------------------------------------------------------------------
   ## simulate the age at onset for the family member: each generation may have different frailty, so simulated seperately.
-      
-
-  if(variation=="secondgene"){
-    if(interaction) x <- cbind(gender, majorgene, gender*majorgene, secondgene)
-    else x <- cbind(gender, majorgene, secondgene)
-  }
-  else if(interaction) x <- cbind(gender, majorgene, gender*majorgene)
-  else   x <- cbind(gender, majorgene)
   
+  ## x matrix and xbeta 
+  x <- cbind(gender, majorgene)
+  if(interaction) x <- cbind(gender, majorgene, gender*majorgene)
+  if(variation == "secondgene") x <- cbind(x, secondgene)
+  if(add.x) x <- cbind(x, newx)
   xbeta <- c(x %*% vbeta)
   
   # gen3 = generation 1,2,3   
@@ -227,25 +257,23 @@ if (SecNum > 0) { ## at least one sample in second generation
   affected <- (proband==1)
 
   #------------------------------------------------------------------------------
-  if(variation == "frailty"){
-#  if(TRUE){
+  if(variation == "frailty" | variation == "kinship"){
     uni <- runif(nIndi, 0, 1)
-    ageonset <- apply(cbind(xbeta,uni), 1, inv.surv, base.dist=base.dist, parms=parms, alpha=alpha)
-  }
-  else{
+    ageonset <- apply(cbind(xbeta,alpha, uni), 1, inv2.surv, base.dist=base.dist, parms=base.parms)
+  } else{
   ## generating ageonsets for probands
    genepos <- pos[proband==1]
    xvbeta <- xbeta[genepos]
    affage <- censorage[genepos]
    affage.min <- ifelse(affage>agemin, affage-agemin, 0)
    uni <- runif(length(genepos), 0,1)
-   ageonset[genepos] <- apply(cbind(xvbeta,affage.min, uni), 1, inv.survp, base.dist=base.dist, parms=parms, alpha=alpha)
+   ageonset[genepos] <- apply(cbind(xvbeta,affage.min, uni), 1, inv.survp, base.dist=base.dist, parms=base.parms, alpha=alpha)
   
   ## generate ageonset for non-affected ones
    genepos <- pos[proband==0]
    xvbeta <- xbeta[genepos]
    uni <- runif(length(genepos), 0, 1)
-   ageonset[genepos] <- apply(cbind(xvbeta,uni), 1, inv.surv, base.dist=base.dist, parms=parms, alpha=alpha)
+   ageonset[genepos] <- apply(cbind(xvbeta,uni), 1, inv.surv, base.dist=base.dist, parms=base.parms, alpha=alpha)
   }
   
   ageonset <- ageonset+agemin
@@ -261,12 +289,20 @@ if (SecNum > 0) { ## at least one sample in second generation
 
   fsize <- length(famID) # family size
   naff <- sum(status) # number of affected in the family
-  tmpdata<-cbind(
-  famID, indID, gender, motherID, fatherID, proband, generation,
-  majorgene=disgene.m, secondgene=disgene.s, ageonset, currentage, 
-  time, status, mgene, relation, fsize, naff)
+  if(add.x){
+    tmpdata<-cbind(
+    famID, indID, gender, motherID, fatherID, proband, generation,
+    majorgene=disgene.m, secondgene=disgene.s, ageonset, currentage, 
+    time, status, mgene, newx, relation, fsize, naff)
+  }
+  else 
+    tmpdata <- cbind(
+    famID, indID, gender, motherID, fatherID, proband, generation,
+    majorgene=disgene.m, secondgene=disgene.s, ageonset, currentage, 
+    time, status, mgene, relation, fsize, naff)
+
   }#Close for if (SecNum > 0)
     
 return(tmpdata)
 
-}
+}
\ No newline at end of file
